package com.ruoyi.ems.service;

import java.util.List;
import com.ruoyi.ems.domain.OpEnergyStrategy;

/**
 * 能源策略Service接口
 * 
 * @author ruoyi
 * @date 2024-08-08
 */
public interface IOpEnergyStrategyService
{
    /**
     * 查询能源策略
     * 
     * @param id 能源策略主键
     * @return 能源策略
     */
     OpEnergyStrategy selectOpEnergyStrategyById(Long id);

    /**
     * 查询能源策略列表
     * 
     * @param opEnergyStrategy 能源策略
     * @return 能源策略集合
     */
     List<OpEnergyStrategy> selectOpEnergyStrategyList(OpEnergyStrategy opEnergyStrategy);

    /**
     * 新增能源策略
     * 
     * @param opEnergyStrategy 能源策略
     * @return 结果
     */
     int insertOpEnergyStrategy(OpEnergyStrategy opEnergyStrategy);

    /**
     * 修改能源策略
     * 
     * @param opEnergyStrategy 能源策略
     * @return 结果
     */
     int updateOpEnergyStrategy(OpEnergyStrategy opEnergyStrategy);

    /**
     * 批量删除能源策略
     * 
     * @param ids 需要删除的能源策略主键集合
     * @return 结果
     */
     int deleteOpEnergyStrategyByIds(Long[] ids);

    /**
     * 删除能源策略信息
     * 
     * @param id 能源策略主键
     * @return 结果
     */
     int deleteOpEnergyStrategyById(Long id);
}
